@@ -1,7 +1,10 @@
-import re
+from logging import getLogger
 
+from restfx import __meta__
 from restfx.util import utils
 
+logger = getLogger(__meta__.name)
+
 
 class Logger:
     _LOGGERS = {}
@@ -30,7 +33,8 @@ class Logger:
             # noinspection PyUnresolvedReferences
             self.custom_logger(level, message, e)
             return
-        self.print(level, message)
+        getattr(logger, level)(message)
+        # self.print(level, message)
 
     def debug(self, message):
         self.log('debug', message)
@@ -75,7 +79,7 @@ class Logger:
 
     @classmethod
     def get(cls, app_id: str):
-        logger = cls._LOGGERS.get(app_id, None)
-        if logger is None:
-            logger = Logger(app_id)
-        return logger
+        _logger = cls._LOGGERS.get(app_id, None)
+        if _logger is None:
+            _logger = Logger(app_id)
+        return _logger
